#!/bin/ksh
## Script que aleatoriza wallpaper
## Dependencias: ImageMagick
#
# Autor: Tuxliban Torvalds <o-sanchez@linuxmail.org>
#
# Lista de códigos de salida
#	0 - éxito
#	10 - Dependencia no satisfecha
#	11 - Wallpaper no se modificó

function deps {
	if ! command -v magick >/dev/null; then
		printf '%s\n' "ImageMagick no disponible, instálelo"
		return 10
	else
		return 0
	fi
}

# Obtener resolución de pantalla
read -r RES < /sys/class/graphics/fb0/virtual_size

# Path wallpapers
DIR_WALL="$HOME/Datos/Imágenes/Wallpapers"

# Obtener una lista de los archivos de imagen en el directorio de wallpapers
WALL=("$DIR_WALL"/*.{jpg,jpeg,png})

# Obtener un número aleatorio entre 0 y la cantidad de archivos de imagen en la lista
((RAND_INDEX=RANDOM % ${#WALL[@]}))

# Obtener el nombre del archivo de imagen seleccionado
RAND_IMG="${WALL[$RAND_INDEX]}"

if deps; then
	# Comprobar que el archivo seleccionado exista
	if [[ -f $RAND_IMG ]]; then
	
		# Si el archivo existe, configurarlo como wallpaper
		display -resize "!${RES/,/x}" -window root "$RAND_IMG"
		exit 0
	else
		print "El archivo $RAND_IMG no existe."
		if [[ ! -f $RAND_IMG ]]; then
			((RAND_INDEX=RANDOM % ${#WALL[@]}))
			RAND_IMG="${WALL[$RAND_INDEX]}"
			display -resize "!${RES/,/x}" -window root "$RAND_IMG"
		fi
		exit 11
	fi
else
	exit 10
fi
